@@ -2,16 +2,6 @@ use super::*;
 use std::convert::TryFrom;
 
 impl Module {
-    /// Encode this Wasm module into bytes.
-    pub fn to_bytes(&self) -> Vec<u8> {
-        self.inner.to_bytes()
-    }
-}
-
-impl<C> ConfiguredModule<C>
-where
-    C: Config,
-{
     /// Encode this Wasm module into bytes.
     pub fn to_bytes(&self) -> Vec<u8> {
         self.encoded().finish()
@@ -322,23 +312,19 @@ fn translate_entity_type(ty: &EntityType) -> wasm_encoder::EntityType {
     }
 }
 
-fn translate_limits(limits: &Limits) -> wasm_encoder::Limits {
-    wasm_encoder::Limits {
-        min: limits.min,
-        max: limits.max,
-    }
-}
-
 fn translate_table_type(ty: &TableType) -> wasm_encoder::TableType {
     wasm_encoder::TableType {
         element_type: translate_val_type(ty.elem_ty),
-        limits: translate_limits(&ty.limits),
+        minimum: ty.minimum,
+        maximum: ty.maximum,
     }
 }
 
 fn translate_memory_type(ty: &MemoryType) -> wasm_encoder::MemoryType {
     wasm_encoder::MemoryType {
-        limits: translate_limits(&ty.limits),
+        minimum: ty.minimum,
+        maximum: ty.maximum,
+        memory64: ty.memory64,
     }
 }
 
